@@ -575,8 +575,6 @@ class VariableOsDiskFormat(ReadonlyVariable):
                 except BtrfsError:
                     pass
             return fs
-        b = [x for x in self.Get('os_disk_dev')]
-        a = [getFormat(x) for x in self.Get('os_disk_dev')]
         return [getFormat(x) for x in self.Get('os_disk_dev')]
 
 
